@@ -36,7 +36,7 @@ use base qw(
     Clownfish::CFC::Perl::Build::Charmonic
 );
 
-our $VERSION = '0.006000005';
+our $VERSION = '0.006001';
 $VERSION = eval $VERSION;
 
 use File::Spec::Functions qw( catdir catfile updir rel2abs );
@@ -154,8 +154,10 @@ sub ACTION_code {
     my $error = system("$^X -Mblib -MClownfish::Test -e1");
     if ($error) {
         print STDERR "Build succeeded, but 'use Clownfish::Test' failed.\n";
-        my $makefile = do { local(@ARGV, $/) = 'Makefile'; <> };
-        print STDERR "Contents of Makefile:\n$makefile";
+        if ($ENV{AUTOMATED_TESTING}) {
+            my $makefile = do { local(@ARGV, $/) = 'Makefile'; <> };
+            print STDERR "\nContents of Makefile:\n$makefile";
+        }
         die;
     }
 }
